Check the number of sets of test statistics that have a higher (less significant) lfdr value
than other sets with test statistics of uniformly smaller magnitudes.
Usage
check_incongruous(zMatrix, lfdrVec)
Value
A vector with all the indices of all sets that have a higher lfdr value those a set
with smaller test statistic magnitudes.
Arguments
zMatrix
J*K vector of all test statistics.
lfdrVec
J*1 vector of lfdr values corresponding to each set of test statistics.