powered by
Find maximum means for each dimension in null settings.
find_max_means(muInfo)
A K*1 vector of the maximum means for each dimension under the null.
A list with 2^K elements, where each element is a matrix with K rows and Mb columns.
initMuList <- list(matrix(data=0, nrow=2, ncol=1), matrix(data=c(0, 3, 0, 6), nrow=2), matrix(data=c(3, 0, 6, 0), nrow=2), matrix(data=c(8, 8), nrow=2)) find_max_means(initMuList)
Run the code above in your browser using DataLab